#!/bin/bash -e 

#grom=/gromacs/gromacs-2020.2/bin/gmx
grom=/usr/bin/gmx
#
# Variables to use the system information (.tpr), index and full
# trajectory of the simulation
tpr=../../3_Minimization/min1.tpr
index=../../2_Setup/index.ndx
xtc=../1_traj/traj_all.xtc

# The hbond module quantifies and determines the number of hydrogen bonds (hbonds)
# in a given trajectory or structure file provided in the -f flag.
# This module allows for calculations as:
# - function of time or the average number of hbonds between two index groups; 
# - distance or angle distribution of all selected hbonds;
# - number of helical-hbonds in proteins between a given residue range;
# 
# To make use of this module, the user must define in their index (.ndx) file
# the groups of interest. In this example, two separate calculations are done
# on each of the ligands ("Mon_A_13b" and "Mon_B_13b") bound to the "Mpro" protein.
# These calculations give an estimate of how many bonds are stabilizing the ligand to each 
# protein monomer throughout the simulation. 

$grom hbond -f $xtc \
	     -s $tpr \
	     -num Hbond_MPro-and-LigandA.xvg \
	     -n $index <<EOF
Mon_A_13b
MPro
EOF

$grom hbond -f $xtc \
	     -s $tpr \
	     -num Hbond_MPro-and-LigandB.xvg \
	     -n $index <<EOF
Mon_B_13b
MPro
EOF

# 
# Application of a smoothing function (sliding window average)
# to the data files and removal of headings. The 50 points
# window (w=50) corresponds to sliding averages of 5 ns.
for output in MPro-and-LigandA MPro-and-LigandB
do
    awk -v w=50 '!/^(#|@)/{n++;h1[n]=$2};END{for (i=1;i<=n-w+1;i++){s1=0; for (k=0;k<=w-1;k++) {s1+=h1[i+k]}; print skip+(((i+w-1)-(w/2)))/10, s1/w}}' \
        Hbond_${output}.xvg > Hbond_${output}_average.xvg
done


# Cleanup
rm -f *~ *# .*~ .*#

exit 0
