#! /bin/bash
Dir=`pwd`

# Gnuplot is a command-line utility program for data visualization and generate graphics. 
# This script will generate a .gp file with several inscrutions for example:
#  -Border settings;  -Axis manipulation (range and tics); 
#  -File type;        -Size, color and type of data representation (lines, points, etc.)
#  -Data selection by column; -Font type and size:
#  -Labels and keys;  -Multiplot and more advanced type of graphical plots.

file=Hbonds

cat <<EOF > $file.gp

set term postscript enhanced color solid "Times, 22" 
set encoding iso_8859_1
set border 31 lt -1 lw 3
set output "$file.eps"
set rmargin 0
set tmargin 0
set lmargin 5.0
set bmargin 1.5

set xlabel "Time (ns)"
set xrange [0:]
set xtics 0,20 nomirror
set mxtics 2

set ylabel "Number of H-bonds"
set yrange [0:5]
set ytics 0,1 nomirror
set mytics 2

set key top horizontal right maxcols 2 font ",22"

plot \
     "Hbond_MPro-and-LigandA_average.xvg"  u 1:2 w l lt 1 lw 8 lc rgb "#0000FF" title "M^{Pro}- LigA", \
     "Hbond_MPro-and-LigandB_average.xvg"  u 1:2 w l lt 2 lw 8 lc rgb "#FF0000" title "M^{Pro}- LigB", \

EOF

# After generating the .gp file, we run the program gnuplot by giving the file as input.
# If no error is reported, a ".eps" should be in your folder and it will be converted to a .pdf file. 
gnuplot $file.gp
ps2pdf $file.eps
# cleanup
rm -f $file.{gp,eps}

